Name:           libosmscout
Version:        2024.06.02.1
Release:        %{autorelease}
Summary:        Library for offline map rendering, routing and location lookup

License:        LGPL-2.1-only
URL:            https://libosmscout.sourceforge.net/
Source:         https://github.com/Framstag/libosmscout/archive/v%{version}/libosmscout-%{version}.tar.gz
Patch:          installlibs.patch
# Does not build on this architecture
ExcludeArch:    i686

BuildRequires:  cmake
BuildRequires:  gcc-c++
BuildRequires:  cairo-devel
BuildRequires:  freeglut-devel
BuildRequires:  freetype-devel
BuildRequires:  glfw-devel
BuildRequires:  glm-devel
# Not yet in Fedora
#BuildRequires:  libagg-devel
BuildRequires:  libgdiplus-devel
BuildRequires:  libglvnd-devel
BuildRequires:  libpng-devel
BuildRequires:  libxml2-devel
BuildRequires:  marisa-devel
BuildRequires:  mesa-libGLU-devel
BuildRequires:  pango-devel
BuildRequires:  protobuf-compiler
BuildRequires:  protobuf-devel
BuildRequires:  qt6-qtbase-devel
BuildRequires:  qt6-qtlocation-devel
BuildRequires:  qt6-qtmultimedia-devel
BuildRequires:  qt6-qtsvg-devel
BuildRequires:  qt6-qttools-devel
BuildRequires:  qt6-qt5compat-devel
BuildRequires:  tbb
# Tests
BuildREquires: catch-devel
# Documentation
BuildRequires:  doxygen

%description
Libosmscout is a C++ library for offline map rendering, routing and location
lookup based on OpenStreetMap data.

%package devel
Summary:  Files to build applications with libosmscout
Requires: %{name}%{?_isa} = %{version}-%{release}

%description devel
Development files for libosmscout to enable building applications that use it.

%package doc
Summary: Documentation for libosmscout
BuildArch: noarch

%description doc
HTML documentation for libosmcount

%prep
%autosetup -p1


%build
%cmake -DOSMSCOUT_BUILD_DEMOS=OFF -DCMAKE_INSTALL_LIBDIR=%{_libdir}
%cmake_build


%install
%cmake_install

%check
# Disable failing tests
%ctest -E ^PerformanceTest-Qt*

%files
%license LICENSE
%doc README.md
%{_bindir}/Import
%{_bindir}/BasemapImport
%{_bindir}/DumpData
%{_bindir}/PublicTransportMap
%{_bindir}/OSMScout2
%{_bindir}/StyleEditor
%{_libdir}/libosmscout.so.1.1.1
%{_libdir}/libosmscout_import.so.1.1.1
%{_libdir}/libosmscout_gpx.so.1.1.1
%{_libdir}/libosmscout_client_qt.so.1.1.1
%{_libdir}/libosmscout_client.so.1.1.1
%{_libdir}/libosmscout_map_svg.so.1.1.1
%{_libdir}/libosmscout_map_qt.so.1.1.1
%{_libdir}/libosmscout_map_cairo.so.1.1.1
%{_libdir}/libosmscout_map.so.1.1.1

%files devel
%{_includedir}/osmscout/
%{_includedir}/osmscoutimport/
%{_includedir}/osmscoutclientqt/
%{_includedir}/osmscoutclient/
%{_includedir}/osmscoutmapsvg/
%{_includedir}/osmscoutmapqt/
%{_includedir}/osmscoutmapcairo/
%{_includedir}/osmscoutmap/
%{_includedir}/osmscoutgpx/
%{_libdir}/libosmscout.so
%{_libdir}/libosmscout_import.so
%{_libdir}/libosmscout_gpx.so
%{_libdir}/libosmscout_client_qt.so
%{_libdir}/libosmscout_client.so
%{_libdir}/libosmscout_map_svg.so
%{_libdir}/libosmscout_map_qt.so
%{_libdir}/libosmscout_map_cairo.so
%{_libdir}/pkgconfig/osmscout_import.pc
%{_libdir}/pkgconfig/osmscout_gpx.pc
%{_libdir}/pkgconfig/osmscout_client_qt.pc
%{_libdir}/pkgconfig/osmscout_client.pc
%{_libdir}/pkgconfig/osmscout_map_svg.pc
%{_libdir}/pkgconfig/osmscout_map_qt.pc
%{_libdir}/pkgconfig/osmscout_map_cairo.pc
%{_libdir}/pkgconfig/osmscout_map.pc

%files doc
%license LICENSE
%{_datadir}/osmscout/docs/

%changelog
%autochangelog- 
